aboutsummaryrefslogtreecommitdiff
path: root/src/client/mac/handler/exception_handler.h
diff options
context:
space:
mode:
authormmentovai <mmentovai@4c0a9323-5329-0410-9bdc-e9ce6186880e>2007-02-14 19:51:05 +0000
committermmentovai <mmentovai@4c0a9323-5329-0410-9bdc-e9ce6186880e>2007-02-14 19:51:05 +0000
commite5dc60822e5938fea2ae892ccddb906641ba174e (patch)
treed7d4a8e94fee7bdb4eee6501221d92595ebd5f02 /src/client/mac/handler/exception_handler.h
parentChange the symbol table parsing so that it will only use symbols that are fro... (diff)
downloadbreakpad-e5dc60822e5938fea2ae892ccddb906641ba174e.tar.xz
Rename Airbag to Breakpad.
git-svn-id: http://google-breakpad.googlecode.com/svn/trunk@122 4c0a9323-5329-0410-9bdc-e9ce6186880e
Diffstat (limited to 'src/client/mac/handler/exception_handler.h')
-rw-r--r--src/client/mac/handler/exception_handler.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/client/mac/handler/exception_handler.h b/src/client/mac/handler/exception_handler.h
index 0d1232aa..dcc61cb7 100644
--- a/src/client/mac/handler/exception_handler.h
+++ b/src/client/mac/handler/exception_handler.h
@@ -40,7 +40,7 @@
#include <string>
-namespace google_airbag {
+namespace google_breakpad {
using std::string;
@@ -48,13 +48,13 @@ struct ExceptionParameters;
class ExceptionHandler {
public:
// A callback function to run before Airbag performs any substantial
// processing of an exception. A FilterCallback is called before writing
// a minidump. context is the parameter supplied by the user as
// callback_context when the handler was created.
//
// If a FilterCallback returns true, Airbag will continue processing,
// attempting to write a minidump. If a FilterCallback returns false, Airbag
// will immediately report the exception as unhandled without writing a
// minidump, allowing another handler the opportunity to handle it.
typedef bool (*FilterCallback)(void *context);
@@ -64,7 +64,7 @@ class ExceptionHandler {
// file is <dump_dir>/<minidump_id>.dmp.
// |context| is the value passed into the constructor.
// |succeeded| indicates whether a minidump file was successfully written.
// Return true if the exception was fully handled and airbag should exit.
// Return false to allow any other exception handlers to process the
// exception.
typedef bool (*MinidumpCallback)(const char *dump_dir,
@@ -183,6 +183,6 @@ class ExceptionHandler {
bool use_minidump_write_mutex_;
};
-} // namespace google_airbag
+} // namespace google_breakpad
#endif // CLIENT_MAC_HANDLER_EXCEPTION_HANDLER_H__
@@ -48,13 +48,13 @@ struct ExceptionParameters;
class ExceptionHandler {
public:
- // A callback function to run before Airbag performs any substantial
+ // A callback function to run before Breakpad performs any substantial
// processing of an exception. A FilterCallback is called before writing
// a minidump. context is the parameter supplied by the user as
@@ -48,13 +48,13 @@ struct ExceptionParameters;
// callback_context when the handler was created.
//
- // If a FilterCallback returns true, Airbag will continue processing,
- // attempting to write a minidump. If a FilterCallback returns false, Airbag
+ // If a FilterCallback returns true, Breakpad will continue processing,
+ // attempting to write a minidump. If a FilterCallback returns false, Breakpad
// will immediately report the exception as unhandled without writing a
// minidump, allowing another handler the opportunity to handle it.
@@ -64,7 +64,7 @@ class ExceptionHandler {
// |context| is the value passed into the constructor.
// |succeeded| indicates whether a minidump file was successfully written.
- // Return true if the exception was fully handled and airbag should exit.
+ // Return true if the exception was fully handled and breakpad should exit.
// Return false to allow any other exception handlers to process the
// exception.